summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/kernel/tqpainter.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-08-09 22:25:47 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-08-09 22:25:47 -0500
commiteaa7ee2e0bbca40ba3173c4304f81957e8964291 (patch)
tree4f793aa48a5080aedc94ce6e519c3b86708f2b88 /tqtinterface/qt4/src/kernel/tqpainter.cpp
parent79a9d7a46a20d4a0923bc06fc471fdc2176ef865 (diff)
downloadexperimental-eaa7ee2e0bbca40ba3173c4304f81957e8964291.tar.gz
experimental-eaa7ee2e0bbca40ba3173c4304f81957e8964291.zip
rename the following methods:
tqfind find tqreplace replace tqcontains contains
Diffstat (limited to 'tqtinterface/qt4/src/kernel/tqpainter.cpp')
-rw-r--r--tqtinterface/qt4/src/kernel/tqpainter.cpp32
1 files changed, 16 insertions, 16 deletions
diff --git a/tqtinterface/qt4/src/kernel/tqpainter.cpp b/tqtinterface/qt4/src/kernel/tqpainter.cpp
index 66596f5..6d48128 100644
--- a/tqtinterface/qt4/src/kernel/tqpainter.cpp
+++ b/tqtinterface/qt4/src/kernel/tqpainter.cpp
@@ -1518,7 +1518,7 @@ typedef TQPtrStack<TQWMatrix> TQWMatrixStack;
\list
\i font() is the currently set font. If you set a font that isn't
- available, TQt tqfinds a close match. In fact font() returns what
+ available, TQt finds a close match. In fact font() returns what
you set using setFont() and fontInfo() returns the font actually
being used (which may be the same).
@@ -1594,7 +1594,7 @@ typedef TQPtrStack<TQWMatrix> TQWMatrixStack;
The most common functions used are scale(), rotate(), translate()
and shear(), all of which operate on the tqworldMatrix().
- setWorldMatrix() can tqreplace or add to the currently set
+ setWorldMatrix() can replace or add to the currently set
tqworldMatrix().
setViewport() sets the rectangle on which TQPainter operates. The
@@ -1739,7 +1739,7 @@ typedef TQPtrStack<TQWMatrix> TQWMatrixStack;
/*!
\enum TQt::AlignmentFlags
- This enum type is used to describe tqalignment. It tqcontains
+ This enum type is used to describe tqalignment. It contains
horizontal and vertical flags.
The horizontal flags are:
@@ -2232,17 +2232,17 @@ static TQPaintDeviceDict *pdev_dict = 0;
/*!
Redirects all paint commands for a paint tqdevice, \a pdev, to
- another paint tqdevice, \a tqreplacement, unless \a tqreplacement is 0.
- If \a tqreplacement is 0, the redirection for \a pdev is removed.
+ another paint tqdevice, \a replacement, unless \a replacement is 0.
+ If \a replacement is 0, the redirection for \a pdev is removed.
- In general, you'll probably tqfind calling TQPixmap::grabWidget() or
+ In general, you'll probably find calling TQPixmap::grabWidget() or
TQPixmap::grabWindow() is an easier solution.
*/
-void TQPainter::redirect( TQPaintDevice *pdev, TQPaintDevice *tqreplacement )
+void TQPainter::redirect( TQPaintDevice *pdev, TQPaintDevice *replacement )
{
if ( pdev_dict == 0 ) {
- if ( tqreplacement == 0 )
+ if ( replacement == 0 )
return;
pdev_dict = new TQPaintDeviceDict;
TQ_CHECK_PTR( pdev_dict );
@@ -2251,8 +2251,8 @@ void TQPainter::redirect( TQPaintDevice *pdev, TQPaintDevice *tqreplacement )
if ( pdev == 0 )
qWarning( "TQPainter::redirect: The pdev argument cannot be 0" );
#endif
- if ( tqreplacement ) {
- pdev_dict->insert( pdev, tqreplacement );
+ if ( replacement ) {
+ pdev_dict->insert( pdev, replacement );
} else {
pdev_dict->remove( pdev );
if ( pdev_dict->count() == 0 ) {
@@ -2264,11 +2264,11 @@ void TQPainter::redirect( TQPaintDevice *pdev, TQPaintDevice *tqreplacement )
/*!
\internal
- Returns the tqreplacement for \a pdev, or 0 if there is no tqreplacement.
+ Returns the replacement for \a pdev, or 0 if there is no replacement.
*/
TQPaintDevice *TQPainter::redirect( TQPaintDevice *pdev )
{
- return pdev_dict ? pdev_dict->tqfind( pdev ) : 0;
+ return pdev_dict ? pdev_dict->find( pdev ) : 0;
}
/*!
@@ -2799,7 +2799,7 @@ const TQWMatrix &TQPainter::tqworldMatrix() const
transformation.
If \a combine is TRUE, then \a m is combined with the current
- transformation matrix, otherwise \a m tqreplaces the current
+ transformation matrix, otherwise \a m replaces the current
transformation matrix.
If \a m is the identity matrix and \a combine is FALSE, this
@@ -4136,7 +4136,7 @@ void TQPainter::fix_neg_rect( int *x, int *y, int *w, int *h )
//
// The drawText function takes two special parameters; 'internal' and 'brect'.
//
// The 'internal' parameter tqcontains a pointer to an array of encoded
// information that keeps internal tqgeometry data.
// If the drawText function is called repeatedly to display the same text,
// it makes sense to calculate text width and linebreaks the first time,
@@ -4145,7 +4145,7 @@ void TQPainter::fix_neg_rect( int *x, int *y, int *w, int *h )
// The 'internal' parameter will not be used if it is a null pointer.
// The 'internal' parameter will be generated if it is not null, but points
// to a null pointer, i.e. internal != 0 && *internal == 0.
// The 'internal' parameter will be used if it tqcontains a non-null pointer.
//
// If the 'brect parameter is a non-null pointer, then the bounding rectangle
// of the text will be returned in 'brect'.
@@ -4255,7 +4255,7 @@ void qt_format_text( const TQFont& font, const TQRect &_r,
TQFontMetrics fm( fnt );
TQString text = str;
// str.setLength() always does a deep copy, so the tqreplacement
// code below is safe.
text.setLength( len );
// compatible behaviour to the old implementation. Replace
@@ -4136,7 +4136,7 @@ void TQPainter::fix_neg_rect( int *x, int *y, int *w, int *h )
// The drawText function takes two special parameters; 'internal' and 'brect'.
//
-// The 'internal' parameter tqcontains a pointer to an array of encoded
+// The 'internal' parameter contains a pointer to an array of encoded
// information that keeps internal tqgeometry data.
// If the drawText function is called repeatedly to display the same text,
@@ -4145,7 +4145,7 @@ void TQPainter::fix_neg_rect( int *x, int *y, int *w, int *h )
// The 'internal' parameter will be generated if it is not null, but points
// to a null pointer, i.e. internal != 0 && *internal == 0.
-// The 'internal' parameter will be used if it tqcontains a non-null pointer.
+// The 'internal' parameter will be used if it contains a non-null pointer.
//
// If the 'brect parameter is a non-null pointer, then the bounding rectangle
@@ -4255,7 +4255,7 @@ void qt_format_text( const TQFont& font, const TQRect &_r,
TQFontMetrics fm( fnt );
TQString text = str;
- // str.setLength() always does a deep copy, so the tqreplacement
+ // str.setLength() always does a deep copy, so the replacement
// code below is safe.
text.setLength( len );